@@ -1,6 +1,6 @@
 package SADI::Simple::AsyncService;
-BEGIN {
-  $SADI::Simple::AsyncService::VERSION = '0.007';
+{
+  $SADI::Simple::AsyncService::VERSION = '0.008';
 }
 
 use strict;
@@ -264,6 +264,7 @@ sub invoke {
             # save empty output model before we begin
             $self->store($output_model, NOT_FINISHED, $poll_id);
             $self->process_it(\@inputs, $input_model, $output_model);
+            $self->_type_outputs($output_model, \@inputs);
         };
         # error thrown by the implementation class
         if ($@) {
