@@ -1,6 +1,6 @@
 package SADI::Simple::SyncService;
-BEGIN {
-  $SADI::Simple::SyncService::VERSION = '0.007';
+{
+  $SADI::Simple::SyncService::VERSION = '0.008';
 }
 
 use SADI::Simple::Utils;
@@ -121,6 +121,7 @@ sub invoke {
     eval { 
     	my @inputs = $self->_get_inputs_from_model($input_model);
     	$self->process_it(\@inputs, $input_model, $output_model);
+        $self->_type_outputs($output_model, \@inputs);
     };
     # error thrown by the implementation class
     if ($@) {
